#if CLOCK_2
/*
 * sw.c - sense single push sw and pass it to clk_main()
 *   by uratan! 2016.11.12
 */
#include "common.h"
#include <chip.h>

/*
 * I/O pin usage
 *   pin#5: PIO0_1  (input)  - push-SW on LPC810 (same as ISP)
 *   pin#2: PIO0_12 (input)  - push-SW on LPC812 (same as ISP)
 */
//#define GPI_pSW    (1<<1)
#define GPI_pSW    (1<<12)

/*
 * SysTick base interval
 */
#define SYSTICK_Hz   60			/* get 16msec interval */
#warning 'share SYSTICK_Hz with main.c'

/*
 * definition for incoming event
 */
#define PUSH_SHORT    'S'
#define PUSH_LONG     'L'
#warning 'share PUSH_xxxx with clock.c'

/*
 * my functions
 */
void sw_c_init(void);
void sw_tick_procedure(void);

/*
 * variables
 */
VOLATILE int u1_rcv_data;
int push_counter;
int sub_counter;


/* =============================================================== */

/*
 * initial UART1
 */
void sw_c_init(void)
{
	/*
	 * initial my variables
	 */
	push_counter = 0;
	sub_counter = 0;

	u1_rcv_data = -1;
}

/*
 * get 16msec trigger (60Hz)
 */
void sw_tick_procedure(void)
{
	/*
	 * parse the SW condition
	 *   short push -->      'S'
	 *   long push -->       'L'
	 *   continue pushed --> 'S', 'S', 'S', ...
	 */
#define T_TICK       (1000 / SYSTICK_Hz)			/* [msec] */
#define T_PUSH_SHORT   (  50/*[msec]*/ / T_TICK)		/* [n] */
#define T_PUSH_LONG    ( 500/*[msec]*/ / T_TICK)		/* [n] */
#define T_PUSH_REPEAT  (1500/*[msec]*/ / T_TICK)		/* [n] */
#define T_REPEAT       ( 150/*[msec]*/ / T_TICK)		/* [n] */

	if(LPC_GPIO_PORT->PIN[0] & GPI_pSW) {
		/*
		 * not pushed or released, examine length being pushed
		 */
		if(push_counter >= T_PUSH_REPEAT) {
			;		/* was in repeat mode */
		}
		else if(push_counter >= T_PUSH_LONG) {
			u1_rcv_data = PUSH_LONG;
		}
		else if(push_counter >= T_PUSH_SHORT) {
			u1_rcv_data = PUSH_SHORT;
		}
		else {
			;		/* to ignore (push_counter = 0) */
		}

		/*
		 * reset both counter
		 */
		push_counter = 0;
		sub_counter = 0;
	}
	else {
		/*
		 * being pushed
		 */
		push_counter++;
		if(push_counter >= T_PUSH_REPEAT) {
			/*
			 * hold the counter at here,
			 * this also indicate that it entered repeat mode
			 */
			push_counter = T_PUSH_REPEAT;

			/*
			 * count repeat interval
			 */
			sub_counter--;
			if(sub_counter <= 0) {
				u1_rcv_data = PUSH_SHORT;
				sub_counter = T_REPEAT;
			}
		}
	}
}

/* - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - */

/* =============================================================== */
#endif /* CLOCK_2 */
